<?php
	/**
	* VFS class loader
	* @copyright Copyright (C) 2004 Free Software Foundation, Inc. http://www.fsf.org/
	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
	* @package phpgwapi
	* @subpackage vfs
	* @version $Id: class.vfs.inc.php 1040 2008-05-26 10:27:54Z dave $
	*/

	if ( !isset($GLOBALS['phpgw_info']['server']['file_repository']) 
		|| empty($GLOBALS['phpgw_info']['server']['file_repository']) )
	{
		$GLOBALS['phpgw_info']['server']['file_repository'] = 'sql';
	}

	/**
	* Include shared vfs class
	*/
	require_once PHPGW_API_INC . '/class.vfs_shared.inc.php';
	/**
	* Include vfs class
	*/
	require_once PHPGW_API_INC . "/class.vfs_{$GLOBALS['phpgw_info']['server']['file_repository']}.inc.php";
